==> alfresco-repository-23.3.21.3-sources.jar: org/alfresco/repo/bulkimport/BulkFilesystemImporter.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

package org.alfresco.repo.bulkimport;


/**
 * Interface defining a bulk filesystem importer.
 *
 * @since 4.0
 */
public interface BulkFilesystemImporter
{
    /**
     * Initiates a bulk filesystem import.
     * Note: getStatus().inProgress() must be false prior to calling this method or an Exception will be thrown.
     * 
     * @param bulkImportParameters         The target bulk import parameters.
     * @param nodeImporter         The node importer.
     */
    void bulkImport(BulkImportParameters bulkImportParameters, NodeImporter nodeImporter);

    /**
     * Initiates a bulk filesystem import asynchronously i.e. in a background thread.
     * Note: getStatus().inProgress() must be false prior to calling this method or an Exception will be thrown.
     *
     * @param bulkImportParameters         The target bulk import parameters.
     * @param nodeImporter         The node importer.
     */
    void asyncBulkImport(BulkImportParameters bulkImportParameters, NodeImporter nodeImporter);
    
    /**
     * @return A status object that describes the current state of the bulk filesystem importer.
     */
    BulkImportStatus getStatus();
}

==> alfresco-repository-25.3.0.35-sources.jar: org/alfresco/repo/bulkimport/BulkFilesystemImporter.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

package org.alfresco.repo.bulkimport;

/**
 * Interface defining a bulk filesystem importer.
 *
 * @since 4.0
 */
public interface BulkFilesystemImporter
{
    /**
     * Initiates a bulk filesystem import. Note: getStatus().inProgress() must be false prior to calling this method or an Exception will be thrown.
     * 
     * @param bulkImportParameters
     *            The target bulk import parameters.
     * @param nodeImporter
     *            The node importer.
     */
    void bulkImport(BulkImportParameters bulkImportParameters, NodeImporter nodeImporter);

    /**
     * Initiates a bulk filesystem import asynchronously i.e. in a background thread. Note: getStatus().inProgress() must be false prior to calling this method or an Exception will be thrown.
     *
     * @param bulkImportParameters
     *            The target bulk import parameters.
     * @param nodeImporter
     *            The node importer.
     */
    void asyncBulkImport(BulkImportParameters bulkImportParameters, NodeImporter nodeImporter);

    /**
     * @return A status object that describes the current state of the bulk filesystem importer.
     */
    BulkImportStatus getStatus();
}
